Changelog
---------

0.2 (2017-05-15)
++++++++++++++++

* Added support for generating string based on regular expression
  (via "regex" extra package).

0.1 (2017-05-11)
++++++++++++++++

* Initial release.
